==> libaqueous-0.0.1.tar.gz: lib/src/api/room/room.dart <==
import "dart:async";

import 'package:chopper/chopper.dart';
import 'package:libaqueous/src/api/const.dart';
import 'package:libaqueous/src/api/room/model/created_event.dart';
import 'package:libaqueous/src/api/room/model/directory_visibility.dart';
import 'package:libaqueous/src/api/room/model/joined_rooms.dart';
import 'package:libaqueous/src/api/room/model/room_id.dart';
import 'package:libaqueous/src/api/room/model/state_event.dart';

part "room.chopper.dart";

@ChopperApi(baseUrl: MATRIX_CLIENT_R0)
abstract class RoomAPI extends ChopperService {
  static RoomAPI create([ChopperClient client]) => _$RoomAPI(client);

  @Post(url: "/createRoom")
  Future<Response<RoomID>> postCreateRoom(
      @Query("visibility") DirectoryVisibility visibility,
      @Query("room_alias_name") String aliasName,
      @Query("name") String name,
      @Query("topic") String topic,
      @Query("invite") List<String> invite,
      @Query("room_version") String version,
      @Query("initial_state") List<StateEvent> initialState,
      @Query("is_direct") bool isDirect);

  @Put(url: "/directory/room/{roomAlias}")
  Future<Response> putRoomAlias(
      @Path("roomAlias") String roomAlias, @Query("room_id") String roomID);

  @Get(url: "/directory/room/{roomAlias}")
  Future<Response> getRoomAlias(@Path("roomAlias") String roomAlias);

  @Delete(url: "/directory/room/{roomAlias}")
  Future<Response> deleteRoomAlias(@Path("roomAlias") String roomAlias);

  @Get(url: "/joined_rooms")
  Future<Response<JoinedRooms>> getJoinedRooms();

  @Post(url: "/rooms/{roomID}/invite")
  Future<Response> postInvite(@Path("roomID") String roomID,
      @Query("user_id") String userID);

  @Post(url: "/rooms/{roomID}/join")
  Future<Response> postJoin(@Path("roomID") String roomID);

  @Put(url: "/rooms/{roomID}/send/{eventType}/{txID}")
  Future<Response<CreatedEvent>> send(@Path("roomID") String roomID,
      @Path("eventType") String eventType,
      @Path("txID") String txID,
      @Body() content);
}

==> libaqueous-0.0.2.tar.gz: lib/src/api/room/room.dart <==
import "dart:async";

import 'package:chopper/chopper.dart';
import 'package:libaqueous/src/api/const.dart';
import 'package:libaqueous/src/api/room/model/created_event.dart';
import 'package:libaqueous/src/api/room/model/directory_visibility.dart';
import 'package:libaqueous/src/api/room/model/joined_rooms.dart';
import 'package:libaqueous/src/api/room/model/room_id.dart';
import 'package:libaqueous/src/api/room/model/state_event.dart';

part "room.chopper.dart";

@ChopperApi(baseUrl: MATRIX_CLIENT_R0)
abstract class RoomAPI extends ChopperService {
  static RoomAPI create([ChopperClient client]) => _$RoomAPI(client);

  @Post(path: "/createRoom")
  Future<Response<RoomID>> postCreateRoom(
      @Query("visibility") DirectoryVisibility visibility,
      @Query("room_alias_name") String aliasName,
      @Query("name") String name,
      @Query("topic") String topic,
      @Query("invite") List<String> invite,
      @Query("room_version") String version,
      @Query("initial_state") List<StateEvent> initialState,
      @Query("is_direct") bool isDirect);

  @Put(path: "/directory/room/{roomAlias}")
  Future<Response> putRoomAlias(
      @Path("roomAlias") String roomAlias, @Query("room_id") String roomID);

  @Get(path: "/directory/room/{roomAlias}")
  Future<Response> getRoomAlias(@Path("roomAlias") String roomAlias);

  @Delete(path: "/directory/room/{roomAlias}")
  Future<Response> deleteRoomAlias(@Path("roomAlias") String roomAlias);

  @Get(path: "/joined_rooms")
  Future<Response<JoinedRooms>> getJoinedRooms();

  @Post(path: "/rooms/{roomID}/invite")
  Future<Response> postInvite(
      @Path("roomID") String roomID, @Query("user_id") String userID);

  @Post(path: "/rooms/{roomID}/join")
  Future<Response> postJoin(@Path("roomID") String roomID);

  @Put(path: "/rooms/{roomID}/send/{eventType}/{txID}")
  Future<Response<CreatedEvent>> send(
      @Path("roomID") String roomID,
      @Path("eventType") String eventType,
      @Path("txID") String txID,
      @Body() content);
}
